@@ -8,7 +8,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = "2.002";
+our $VERSION = "2.003";
 $VERSION = eval $VERSION;
 
 use LWP::UserAgent;
@@ -105,8 +105,8 @@ sub send_sms {
     	}
     }
     else {
-        my $json = decode_json($res->{'_content'});
-        $self->log("Error " . $res->{'_rc'} . ": " . $json->{error}, 4);
+        my $json = eval { decode_json($res->{'_content'}) };
+        $self->log("Error " . $res->{'_rc'} . ": " . (defined $json ? $json->{error} : 'unexpected error'), 4);
         return 0;
     }
 }
@@ -123,7 +123,7 @@ SMS::Send::CZ::Bulkgate - SMS::Send driver for Bulkgate - Czech Republic
 
 =head1 VERSION
 
-version 2.002
+version 2.003
 
 =head1 SYNOPSIS
 
